Struct Cfgr1
#[repr(transparent)]pub struct Cfgr1(pub u32);Expand description
Configuration register 1
Tuple Fields
0: u32Implementations
impl Cfgr1
impl Cfgr1
pub const fn set_dmacfg(&mut self, val: Dmacfg)
pub const fn set_dmacfg(&mut self, val: Dmacfg)
Direct memory access configuration
pub const fn set_scandir(&mut self, val: Scandir)
pub const fn set_scandir(&mut self, val: Scandir)
Scan sequence direction
pub const fn set_extsel(&mut self, val: u8)
pub const fn set_extsel(&mut self, val: u8)
External trigger selection
pub const fn ovrmod(&self) -> bool
pub const fn ovrmod(&self) -> bool
Overrun management mode (0: ADC_DR is preserved when an overrun is detected, 1: ADC_DR is overwritten with the last conversion result)
pub const fn set_ovrmod(&mut self, val: bool)
pub const fn set_ovrmod(&mut self, val: bool)
Overrun management mode (0: ADC_DR is preserved when an overrun is detected, 1: ADC_DR is overwritten with the last conversion result)
pub const fn set_autoff(&mut self, val: bool)
pub const fn set_autoff(&mut self, val: bool)
Auto-off mode
pub const fn set_discen(&mut self, val: bool)
pub const fn set_discen(&mut self, val: bool)
Discontinuous mode
pub const fn awd1sgl(&self) -> bool
pub const fn awd1sgl(&self) -> bool
Enable the analog watchdog 1 on a single channel (1) or on all channels (0)
pub const fn set_awd1sgl(&mut self, val: bool)
pub const fn set_awd1sgl(&mut self, val: bool)
Enable the analog watchdog 1 on a single channel (1) or on all channels (0)
pub const fn set_awd1en(&mut self, val: bool)
pub const fn set_awd1en(&mut self, val: bool)
Analog watchdog 1 enable
pub const fn set_awd1ch(&mut self, val: u8)
pub const fn set_awd1ch(&mut self, val: u8)
Analog watchdog 1 channel selection